@@ -9,8 +9,10 @@ package Net::BitTorrent::Torrent::Tracker;
     use lib q[./../../../];
     use Net::BitTorrent::Torrent::Tracker::HTTP;
     use Net::BitTorrent::Torrent::Tracker::UDP;
-    our $VERSION_BASE = 50; our $UNSTABLE_RELEASE = 0; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), ($VERSION_BASE / 1000), $UNSTABLE_RELEASE);
-    my (@CONTENTS) = \my (%torrent, %urls);
+    use version qw[qv];
+    our $SVN = q[$Id: Tracker.pm 40 2008-12-02 04:25:26Z sanko@cpan.org $];
+    our $UNSTABLE_RELEASE = 0; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), (version->new((qw$Rev: 40 $)[1])->numify / 1000), $UNSTABLE_RELEASE);
+    my (@CONTENTS) = \my (%torrent, %_urls, %complete, %incomplete);
     my %REGISTRY;
 
     sub new {
@@ -38,47 +40,62 @@ package Net::BitTorrent::Torrent::Tracker;
         $self = bless(\$args->{q[URLs]}->[0], $class);
         $torrent{refaddr $self} = $args->{q[Torrent]};
         weaken $torrent{refaddr $self};
-        $urls{refaddr $self} = [];
+        $complete{refaddr $self}   = 0;
+        $incomplete{refaddr $self} = 0;
+        $_urls{refaddr $self}      = [];
         for my $_url (@{$args->{q[URLs]}}) {
-            push @{$urls{refaddr $self}},
+            push @{$_urls{refaddr $self}},
                 ($_url =~ m[^http://]i
                  ? q[Net::BitTorrent::Torrent::Tracker::HTTP]
                  : q[Net::BitTorrent::Torrent::Tracker::UDP]
                 )->new({URL => $_url, Tier => $self});
         }
+        $torrent{refaddr $self}->_client->_schedule(
+                             {Time   => time,
+                              Code   => sub { shift->_announce(q[started]) },
+                              Object => $self
+                             }
+        ) if $torrent{refaddr $self}->status & 128;
         weaken($REGISTRY{refaddr $self} = $self);
-        @{$urls{refaddr $self}} = shuffle(@{$urls{refaddr $self}});
+        @{$_urls{refaddr $self}} = shuffle(@{$_urls{refaddr $self}});
         return $self;
     }
 
     # Accessors | Public
-    sub urls { return $urls{refaddr +shift}; }
+    sub incomplete { return $incomplete{refaddr +shift} }
+    sub complete   { return $complete{refaddr +shift} }
 
     # Accessors | Private
     sub _client  { return $torrent{refaddr +shift}->_client; }
     sub _torrent { return $torrent{refaddr +shift}; }
-
-    sub _nodes {
-        my ($self) = @_;
-        return compact(map { $_->_nodes } @{$urls{refaddr $self}});
-    }
+    sub _urls    { return $_urls{refaddr +shift}; }
 
     # Methods | Private
+    sub _set_complete {
+        my ($self, $value) = @_;
+        return $complete{refaddr $self} = $value;
+    }
+
+    sub _set_incomplete {
+        my ($self, $value) = @_;
+        return $incomplete{refaddr $self} = $value;
+    }
+
     sub _shuffle {
         my ($self) = @_;
         return (
-               push(@{$urls{refaddr $self}}, shift(@{$urls{refaddr $self}})));
+             push(@{$_urls{refaddr $self}}, shift(@{$_urls{refaddr $self}})));
     }
 
     sub _announce {
         my ($self, $event) = @_;
         return if not defined $self;
-        return if not defined $urls{refaddr $self};
-        return if not scalar @{$urls{refaddr $self}};
-        return $urls{refaddr $self}->[0]->_announce($event ? $event : ());
+        return if not defined $_urls{refaddr $self};
+        return if not scalar @{$_urls{refaddr $self}};
+        return $_urls{refaddr $self}->[0]->_announce($event ? $event : ());
     }
 
-    sub as_string {
+    sub _as_string {
         my ($self, $advanced) = @_;
         my $dump = !$advanced ? $$self : sprintf <<'END',
 Net::BitTorrent::Torrent::Tracker
@@ -88,8 +105,10 @@ Incomplete: %d
 Number of URLs: %d
     %s
 END
-            scalar(@{$urls{refaddr $self}}),
-            join qq[\r\n    ], map { $_->url() } @{$urls{refaddr $self}};
+            $complete{refaddr $self},
+            $incomplete{refaddr $self},
+            scalar(@{$_urls{refaddr $self}}),
+            join qq[\r\n    ], map { $_->_url() } @{$_urls{refaddr $self}};
         return defined wantarray ? $dump : print STDERR qq[$dump\n];
     }
 
@@ -143,19 +162,6 @@ swarm.
 Returns the number of incomplete peers the tracker says are present in
 the swarm.
 
-=item C<urls()>
-
-Returns a list of related
-L<Net::BitTorrent::Torrent::Tracker::HTTP|Net::BitTorrent::Torrent::Tracker::HTTP>
-and L<Net::BitTorrent::Torrent::Tracker::UDP|Net::BitTorrent::Torrent::Tracker::UDP>
-objects.
-
-=item C<as_string ( [ VERBOSE ] )>
-
-Returns a 'ready to print' dump of the  object's data structure.  If
-called in void context, the structure is printed to C<STDERR>.
-C<VERBOSE> is a boolean value.
-
 =back
 
 =head1 Author
@@ -166,7 +172,7 @@ CPAN ID: SANKO
 
 =head1 License and Legal
 
-Copyright (C) 2008-2009 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
+Copyright (C) 2008 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of The Artistic License 2.0.  See the F<LICENSE>
@@ -182,6 +188,6 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 Neither this module nor the L<Author|/Author> is affiliated with
 BitTorrent, Inc.
 
-=for svn $Id: Tracker.pm 5476ff9 2009-09-07 04:37:45Z sanko@cpan.org $
+=for svn $Id: Tracker.pm 40 2008-12-02 04:25:26Z sanko@cpan.org $
 
 =cut
