@@ -3,7 +3,9 @@ package Net::BitTorrent::Version;
 {
     use strict;
     use warnings;
-    our $VERSION_BASE = 50; our $UNSTABLE_RELEASE = 50; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), ($VERSION_BASE / 1000), $UNSTABLE_RELEASE);
+    use version qw[qv];
+    our $SVN = q[$Id: Version.pm 40 2008-12-02 04:25:26Z sanko@cpan.org $];
+    our $VERSION_BASE = 40; our $UNSTABLE_RELEASE = 0; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), (version->new(($VERSION_BASE))->numify / 1000), $UNSTABLE_RELEASE);
     our $PRODUCT_TOKEN = qq[Net::BitTorrent $VERSION];
 
     sub gen_peerid {
@@ -19,14 +21,20 @@ package Net::BitTorrent::Version;
                       ->[rand(66)]
                       } 1 .. 8
                  ),
-                 q[Riana]
+                 q[Azumi]
              )
             )
         );
     }
 
     sub gen_node_id {
-        return pack(q[H40], join(q[], map { rand(12) } 1 .. 40));
+        return
+            pack(q[a20],
+                 (join(q[],
+                       map { [q[a] .. q[z], q[A] .. q[Z]]->[rand(52)] }
+                           1 .. 20)
+                 )
+            );
     }
     1;
 }
@@ -72,18 +80,18 @@ L<header|/Header> which may be used to identify the software and its
 version, and the L<signature|/Signature> which is... well, it's junk.
 Consider this example:
 
- NB004S-rogzGB1v--git
+ NB004S-rogzGB1v--SVN
 
-Here, C<NB004S> is the header and C<-rogzGB1v--git> is the trailing
+Here, C<NB004S> is the header and C<-rogzGB1v--SVN> is the trailing
 signature.
 
 =head3 Header
 
 The header consists of two uppercase characters ('C<NB>') followed by
-three digits (with leading zeros) representing the distribution version
-and a single character used to (potentially) indicate stability:
-C<S>table or C<U>nstable.  Any deviation from this indicates a bad
-client.  Recent stable builds will be found on CPAN.
+three digits (with leading zeros) representing the SVN revision, and a
+single character used to (potentially) indicate stability: C<S>table or
+C<U>nstable.  Any deviation from this indicates a bad client.  Recent
+stable builds will be found on CPAN.
 
 =head3 Signature
 
@@ -95,7 +103,7 @@ in the following range:
 That is, all uppercase and lowercase letters, decimal digits, as well as
 the hyphen, period, underscore, and tilde (66 total).  These are all
 characters allowed in a URL without being encoded (referred to as
-"Unreserved Characters" in L<rfc 3986|/"rfc3986">).
+"Unreserved Characters" in rfc://3986).
 
 =head2 Version Numbers and Stability
 
@@ -103,7 +111,7 @@ Distribution version numbers will be some value less than one (C<1>) with
 the revision number in the three significant decimal places.
 
 Recent stable builds will be found on CPAN.  Unstable builds will most
-likely be private builds or temporary uploads to CPAN where the package
+likely be SVN checkouts and temporary uploads to CPAN where the package
 name matches C<m[\d\.\d+_\d]>.  See the PAUSE FAQ section entitled
 "Developer Releases" (L<http://www.cpan.org/modules/04pause.html>).
 
@@ -111,25 +119,25 @@ name matches C<m[\d\.\d+_\d]>.  See the PAUSE FAQ section entitled
 
 =over
 
-=item C<NB393S-04.9EraQ--git>
+=item C<NB393S-04.9EraQ--SVN>
 
-This would be the stable CPAN-ready release C<v0.393>.  The C<--git>
+This would be the stable CPAN release C<v0.393>/SVN r393.  The C<--SVN>
 signature does not imply an unstable build.
 
 =item C<NB003X-9E-ayR6-IE<lt>3BT>
 
 Improper Peer ID; the sixth char is neither 'C<S>' nor 'C<U>' and E<lt>
-is a reserved character according to L<rfc: 3986|/"rfc3986">.
+is a reserved character according to rfc://3986.
 
 =item C<NB065U--09Egae69sy8W>
 
-Completely legal Peer ID generated by unstable build around C<v65>.
+Completely legal Peer ID generated by unstable SVN/Dev r65.
 
 =back
 
 =head1 See Also
 
-X<rfc3986>RFC 3986 (URI: Generic Syntax)
+RFC 3986 (URI: Generic Syntax)
 Section 2.3. "Unreserved Characters"
 (http://tools.ietf.org/html/rfc3986#section-2.3)
 
@@ -143,7 +151,7 @@ http://slashdot.org/comments.pl?sid=997033&cid=25390887
 This document and the specification behind it are subject to change.
 All modifications will be documented in the Changes file included with
 this distribution.  All versions of this file can be found in the
-project's git repository.
+project's SVN repository.
 
 =head1 Author
 
@@ -153,7 +161,7 @@ CPAN ID: SANKO
 
 =head1 License and Legal
 
-Copyright (C) 2008-2009 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
+Copyright (C) 2008 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of The Artistic License 2.0.  See the F<LICENSE>
@@ -169,6 +177,6 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 Neither this module nor the L<Author|/Author> is affiliated with
 BitTorrent, Inc.
 
-=for svn $Id: Version.pm 5476ff9 2009-09-07 04:37:45Z sanko@cpan.org $
+=for svn $Id: Version.pm 40 2008-12-02 04:25:26Z sanko@cpan.org $
 
 =cut
